+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|:class:`DNACenterAPI` | :ref:`authentication`                                   | :meth:`authentication_api() <dnacentersdk.api.authentication.Authentication.authentication_api>`                                                                      |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`clients <clients_1_2_10>`                         | :meth:`get_client_detail() <dnacentersdk.api.v1_2_10.clients.Clients.get_client_detail>`                                                                              |
|                      |                                                         | :meth:`get_overall_client_health() <dnacentersdk.api.v1_2_10.clients.Clients.get_overall_client_health>`                                                              |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`command_runner <command_runner_1_2_10>`           | :meth:`get_all_keywords_of_clis_accepted() <dnacentersdk.api.v1_2_10.command_runner.CommandRunner.get_all_keywords_of_clis_accepted>`                                 |
|                      |                                                         | :meth:`run_read_only_commands_on_devices() <dnacentersdk.api.v1_2_10.command_runner.CommandRunner.run_read_only_commands_on_devices>`                                 |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`custom_caller`                                    | :meth:`add_api() <dnacentersdk.api.custom_caller.CustomCaller.add_api>`                                                                                               |
|                      |                                                         | :meth:`call_api() <dnacentersdk.api.custom_caller.CustomCaller.call_api>`                                                                                             |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`devices <devices_1_2_10>`                         | :meth:`add_device() <dnacentersdk.api.v1_2_10.devices.Devices.add_device>`                                                                                            |
|                      |                                                         | :meth:`delete_device_by_id() <dnacentersdk.api.v1_2_10.devices.Devices.delete_device_by_id>`                                                                          |
|                      |                                                         | :meth:`export_device_list() <dnacentersdk.api.v1_2_10.devices.Devices.export_device_list>`                                                                            |
|                      |                                                         | :meth:`get_all_interfaces() <dnacentersdk.api.v1_2_10.devices.Devices.get_all_interfaces>`                                                                            |
|                      |                                                         | :meth:`get_device_by_id() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_by_id>`                                                                                |
|                      |                                                         | :meth:`get_device_by_serial_number() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_by_serial_number>`                                                          |
|                      |                                                         | :meth:`get_device_config_by_id() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_config_by_id>`                                                                  |
|                      |                                                         | :meth:`get_device_config_count() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_config_count>`                                                                  |
|                      |                                                         | :meth:`get_device_config_for_all_devices() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_config_for_all_devices>`                                              |
|                      |                                                         | :meth:`get_device_count() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_count>`                                                                                |
|                      |                                                         | :meth:`get_device_detail() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_detail>`                                                                              |
|                      |                                                         | :meth:`get_device_interface_count() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_interface_count>`                                                            |
|                      |                                                         | :meth:`get_device_interface_count_by_id() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_interface_count_by_id>`                                                |
|                      |                                                         | :meth:`get_device_interface_vlans() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_interface_vlans>`                                                            |
|                      |                                                         | :meth:`get_device_interfaces_by_specified_range() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_interfaces_by_specified_range>`                                |
|                      |                                                         | :meth:`get_device_list() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_list>`                                                                                  |
|                      |                                                         | :meth:`get_device_summary() <dnacentersdk.api.v1_2_10.devices.Devices.get_device_summary>`                                                                            |
|                      |                                                         | :meth:`get_functional_capability_by_id() <dnacentersdk.api.v1_2_10.devices.Devices.get_functional_capability_by_id>`                                                  |
|                      |                                                         | :meth:`get_functional_capability_for_devices() <dnacentersdk.api.v1_2_10.devices.Devices.get_functional_capability_for_devices>`                                      |
|                      |                                                         | :meth:`get_interface_by_id() <dnacentersdk.api.v1_2_10.devices.Devices.get_interface_by_id>`                                                                          |
|                      |                                                         | :meth:`get_interface_by_ip() <dnacentersdk.api.v1_2_10.devices.Devices.get_interface_by_ip>`                                                                          |
|                      |                                                         | :meth:`get_interface_details() <dnacentersdk.api.v1_2_10.devices.Devices.get_interface_details>`                                                                      |
|                      |                                                         | :meth:`get_interface_info_by_id() <dnacentersdk.api.v1_2_10.devices.Devices.get_interface_info_by_id>`                                                                |
|                      |                                                         | :meth:`get_isis_interfaces() <dnacentersdk.api.v1_2_10.devices.Devices.get_isis_interfaces>`                                                                          |
|                      |                                                         | :meth:`get_module_count() <dnacentersdk.api.v1_2_10.devices.Devices.get_module_count>`                                                                                |
|                      |                                                         | :meth:`get_module_info_by_id() <dnacentersdk.api.v1_2_10.devices.Devices.get_module_info_by_id>`                                                                      |
|                      |                                                         | :meth:`get_modules() <dnacentersdk.api.v1_2_10.devices.Devices.get_modules>`                                                                                          |
|                      |                                                         | :meth:`get_network_device_by_ip() <dnacentersdk.api.v1_2_10.devices.Devices.get_network_device_by_ip>`                                                                |
|                      |                                                         | :meth:`get_network_device_by_pagination_range() <dnacentersdk.api.v1_2_10.devices.Devices.get_network_device_by_pagination_range>`                                    |
|                      |                                                         | :meth:`get_organization_list_for_meraki() <dnacentersdk.api.v1_2_10.devices.Devices.get_organization_list_for_meraki>`                                                |
|                      |                                                         | :meth:`get_ospf_interfaces() <dnacentersdk.api.v1_2_10.devices.Devices.get_ospf_interfaces>`                                                                          |
|                      |                                                         | :meth:`get_polling_interval_by_id() <dnacentersdk.api.v1_2_10.devices.Devices.get_polling_interval_by_id>`                                                            |
|                      |                                                         | :meth:`get_polling_interval_for_all_devices() <dnacentersdk.api.v1_2_10.devices.Devices.get_polling_interval_for_all_devices>`                                        |
|                      |                                                         | :meth:`get_wireless_lan_controller_details_by_id() <dnacentersdk.api.v1_2_10.devices.Devices.get_wireless_lan_controller_details_by_id>`                              |
|                      |                                                         | :meth:`register_device_for_wsa() <dnacentersdk.api.v1_2_10.devices.Devices.register_device_for_wsa>`                                                                  |
|                      |                                                         | :meth:`retrieves_all_network_devices() <dnacentersdk.api.v1_2_10.devices.Devices.retrieves_all_network_devices>`                                                      |
|                      |                                                         | :meth:`sync_devices() <dnacentersdk.api.v1_2_10.devices.Devices.sync_devices>`                                                                                        |
|                      |                                                         | :meth:`sync_devices_using_forcesync() <dnacentersdk.api.v1_2_10.devices.Devices.sync_devices_using_forcesync>`                                                        |
|                      |                                                         | :meth:`update_device_role() <dnacentersdk.api.v1_2_10.devices.Devices.update_device_role>`                                                                            |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`fabric_wired <fabric_wired_1_2_10>`               | :meth:`adds_border_device_in_sda_fabric() <dnacentersdk.api.v1_2_10.fabric_wired.FabricWired.adds_border_device_in_sda_fabric>`                                       |
|                      |                                                         | :meth:`deletes_border_device_from_sda_fabric() <dnacentersdk.api.v1_2_10.fabric_wired.FabricWired.deletes_border_device_from_sda_fabric>`                             |
|                      |                                                         | :meth:`gets_border_device_details_from_sda_fabric() <dnacentersdk.api.v1_2_10.fabric_wired.FabricWired.gets_border_device_details_from_sda_fabric>`                   |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`file <file_1_2_10>`                               | :meth:`download_a_file_by_fileid() <dnacentersdk.api.v1_2_10.file.File.download_a_file_by_fileid>`                                                                    |
|                      |                                                         | :meth:`get_list_of_available_namespaces() <dnacentersdk.api.v1_2_10.file.File.get_list_of_available_namespaces>`                                                      |
|                      |                                                         | :meth:`get_list_of_files() <dnacentersdk.api.v1_2_10.file.File.get_list_of_files>`                                                                                    |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`network_discovery <network_discovery_1_2_10>`     | :meth:`create_cli_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.create_cli_credentials>`                                                 |
|                      |                                                         | :meth:`create_http_read_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.create_http_read_credentials>`                                     |
|                      |                                                         | :meth:`create_http_write_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.create_http_write_credentials>`                                   |
|                      |                                                         | :meth:`create_netconf_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.create_netconf_credentials>`                                         |
|                      |                                                         | :meth:`create_snmp_read_community() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.create_snmp_read_community>`                                         |
|                      |                                                         | :meth:`create_snmp_write_community() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.create_snmp_write_community>`                                       |
|                      |                                                         | :meth:`create_snmpv3_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.create_snmpv3_credentials>`                                           |
|                      |                                                         | :meth:`create_update_snmp_properties() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.create_update_snmp_properties>`                                   |
|                      |                                                         | :meth:`delete_all_discovery() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.delete_all_discovery>`                                                     |
|                      |                                                         | :meth:`delete_discovery_by_id() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.delete_discovery_by_id>`                                                 |
|                      |                                                         | :meth:`delete_discovery_by_specified_range() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.delete_discovery_by_specified_range>`                       |
|                      |                                                         | :meth:`delete_global_credentials_by_id() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.delete_global_credentials_by_id>`                               |
|                      |                                                         | :meth:`get_count_of_all_discovery_jobs() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_count_of_all_discovery_jobs>`                               |
|                      |                                                         | :meth:`get_credential_sub_type_by_credential_id() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_credential_sub_type_by_credential_id>`             |
|                      |                                                         | :meth:`get_devices_discovered_by_id() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_devices_discovered_by_id>`                                     |
|                      |                                                         | :meth:`get_discovered_devices_by_range() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_discovered_devices_by_range>`                               |
|                      |                                                         | :meth:`get_discovered_network_devices_by_discovery_id() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_discovered_network_devices_by_discovery_id>` |
|                      |                                                         | :meth:`get_discoveries_by_range() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_discoveries_by_range>`                                             |
|                      |                                                         | :meth:`get_discovery_by_id() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_discovery_by_id>`                                                       |
|                      |                                                         | :meth:`get_discovery_jobs_by_ip() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_discovery_jobs_by_ip>`                                             |
|                      |                                                         | :meth:`get_global_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_global_credentials>`                                                 |
|                      |                                                         | :meth:`get_list_of_discoveries_by_discovery_id() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_list_of_discoveries_by_discovery_id>`               |
|                      |                                                         | :meth:`get_network_devices_from_discovery() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_network_devices_from_discovery>`                         |
|                      |                                                         | :meth:`get_snmp_properties() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.get_snmp_properties>`                                                       |
|                      |                                                         | :meth:`start_discovery() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.start_discovery>`                                                               |
|                      |                                                         | :meth:`update_cli_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.update_cli_credentials>`                                                 |
|                      |                                                         | :meth:`update_global_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.update_global_credentials>`                                           |
|                      |                                                         | :meth:`update_http_read_credential() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.update_http_read_credential>`                                       |
|                      |                                                         | :meth:`update_http_write_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.update_http_write_credentials>`                                   |
|                      |                                                         | :meth:`update_netconf_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.update_netconf_credentials>`                                         |
|                      |                                                         | :meth:`update_snmp_read_community() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.update_snmp_read_community>`                                         |
|                      |                                                         | :meth:`update_snmp_write_community() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.update_snmp_write_community>`                                       |
|                      |                                                         | :meth:`update_snmpv3_credentials() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.update_snmpv3_credentials>`                                           |
|                      |                                                         | :meth:`updates_discovery_by_id() <dnacentersdk.api.v1_2_10.network_discovery.NetworkDiscovery.updates_discovery_by_id>`                                               |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`networks <networks_1_2_10>`                       | :meth:`get_l3_topology_details() <dnacentersdk.api.v1_2_10.networks.Networks.get_l3_topology_details>`                                                                |
|                      |                                                         | :meth:`get_overall_network_health() <dnacentersdk.api.v1_2_10.networks.Networks.get_overall_network_health>`                                                          |
|                      |                                                         | :meth:`get_physical_topology() <dnacentersdk.api.v1_2_10.networks.Networks.get_physical_topology>`                                                                    |
|                      |                                                         | :meth:`get_site_topology() <dnacentersdk.api.v1_2_10.networks.Networks.get_site_topology>`                                                                            |
|                      |                                                         | :meth:`get_topology_details() <dnacentersdk.api.v1_2_10.networks.Networks.get_topology_details>`                                                                      |
|                      |                                                         | :meth:`get_vlan_details() <dnacentersdk.api.v1_2_10.networks.Networks.get_vlan_details>`                                                                              |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`non_fabric_wireless <non_fabric_wireless_1_2_10>` | :meth:`create_and_provision_ssid() <dnacentersdk.api.v1_2_10.non_fabric_wireless.NonFabricWireless.create_and_provision_ssid>`                                        |
|                      |                                                         | :meth:`create_enterprise_ssid() <dnacentersdk.api.v1_2_10.non_fabric_wireless.NonFabricWireless.create_enterprise_ssid>`                                              |
|                      |                                                         | :meth:`delete_and_provision_ssid() <dnacentersdk.api.v1_2_10.non_fabric_wireless.NonFabricWireless.delete_and_provision_ssid>`                                        |
|                      |                                                         | :meth:`delete_enterprise_ssid() <dnacentersdk.api.v1_2_10.non_fabric_wireless.NonFabricWireless.delete_enterprise_ssid>`                                              |
|                      |                                                         | :meth:`get_enterprise_ssid() <dnacentersdk.api.v1_2_10.non_fabric_wireless.NonFabricWireless.get_enterprise_ssid>`                                                    |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`path_trace <path_trace_1_2_10>`                   | :meth:`deletes_pathtrace_by_id() <dnacentersdk.api.v1_2_10.path_trace.PathTrace.deletes_pathtrace_by_id>`                                                             |
|                      |                                                         | :meth:`initiate_a_new_pathtrace() <dnacentersdk.api.v1_2_10.path_trace.PathTrace.initiate_a_new_pathtrace>`                                                           |
|                      |                                                         | :meth:`retrieves_previous_pathtrace() <dnacentersdk.api.v1_2_10.path_trace.PathTrace.retrieves_previous_pathtrace>`                                                   |
|                      |                                                         | :meth:`retrives_all_previous_pathtraces_summary() <dnacentersdk.api.v1_2_10.path_trace.PathTrace.retrives_all_previous_pathtraces_summary>`                           |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`pnp <pnp_1_2_10>`                                 | :meth:`add_a_workflow() <dnacentersdk.api.v1_2_10.pnp.Pnp.add_a_workflow>`                                                                                            |
|                      |                                                         | :meth:`add_device() <dnacentersdk.api.v1_2_10.pnp.Pnp.add_device>`                                                                                                    |
|                      |                                                         | :meth:`add_virtual_account() <dnacentersdk.api.v1_2_10.pnp.Pnp.add_virtual_account>`                                                                                  |
|                      |                                                         | :meth:`claim_a_device_to_a_site() <dnacentersdk.api.v1_2_10.pnp.Pnp.claim_a_device_to_a_site>`                                                                        |
|                      |                                                         | :meth:`claim_device() <dnacentersdk.api.v1_2_10.pnp.Pnp.claim_device>`                                                                                                |
|                      |                                                         | :meth:`delete_device_by_id_from_pnp() <dnacentersdk.api.v1_2_10.pnp.Pnp.delete_device_by_id_from_pnp>`                                                                |
|                      |                                                         | :meth:`delete_workflow_by_id() <dnacentersdk.api.v1_2_10.pnp.Pnp.delete_workflow_by_id>`                                                                              |
|                      |                                                         | :meth:`deregister_virtual_account() <dnacentersdk.api.v1_2_10.pnp.Pnp.deregister_virtual_account>`                                                                    |
|                      |                                                         | :meth:`get_device_by_id() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_device_by_id>`                                                                                        |
|                      |                                                         | :meth:`get_device_count() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_device_count>`                                                                                        |
|                      |                                                         | :meth:`get_device_history() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_device_history>`                                                                                    |
|                      |                                                         | :meth:`get_device_list() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_device_list>`                                                                                          |
|                      |                                                         | :meth:`get_pnp_global_settings() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_pnp_global_settings>`                                                                          |
|                      |                                                         | :meth:`get_smart_account_list() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_smart_account_list>`                                                                            |
|                      |                                                         | :meth:`get_sync_result_for_virtual_account() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_sync_result_for_virtual_account>`                                                  |
|                      |                                                         | :meth:`get_virtual_account_list() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_virtual_account_list>`                                                                        |
|                      |                                                         | :meth:`get_workflow_by_id() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_workflow_by_id>`                                                                                    |
|                      |                                                         | :meth:`get_workflow_count() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_workflow_count>`                                                                                    |
|                      |                                                         | :meth:`get_workflows() <dnacentersdk.api.v1_2_10.pnp.Pnp.get_workflows>`                                                                                              |
|                      |                                                         | :meth:`import_devices_in_bulk() <dnacentersdk.api.v1_2_10.pnp.Pnp.import_devices_in_bulk>`                                                                            |
|                      |                                                         | :meth:`preview_config() <dnacentersdk.api.v1_2_10.pnp.Pnp.preview_config>`                                                                                            |
|                      |                                                         | :meth:`reset_device() <dnacentersdk.api.v1_2_10.pnp.Pnp.reset_device>`                                                                                                |
|                      |                                                         | :meth:`sync_virtual_account_devices() <dnacentersdk.api.v1_2_10.pnp.Pnp.sync_virtual_account_devices>`                                                                |
|                      |                                                         | :meth:`un_claim_device() <dnacentersdk.api.v1_2_10.pnp.Pnp.un_claim_device>`                                                                                          |
|                      |                                                         | :meth:`update_device() <dnacentersdk.api.v1_2_10.pnp.Pnp.update_device>`                                                                                              |
|                      |                                                         | :meth:`update_pnp_global_settings() <dnacentersdk.api.v1_2_10.pnp.Pnp.update_pnp_global_settings>`                                                                    |
|                      |                                                         | :meth:`update_pnp_server_profile() <dnacentersdk.api.v1_2_10.pnp.Pnp.update_pnp_server_profile>`                                                                      |
|                      |                                                         | :meth:`update_workflow() <dnacentersdk.api.v1_2_10.pnp.Pnp.update_workflow>`                                                                                          |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`site_profile <site_profile_1_2_10>`               | :meth:`get_device_details_by_ip() <dnacentersdk.api.v1_2_10.site_profile.SiteProfile.get_device_details_by_ip>`                                                       |
|                      |                                                         | :meth:`provision_nfv() <dnacentersdk.api.v1_2_10.site_profile.SiteProfile.provision_nfv>`                                                                             |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`sites <sites_1_2_10>`                             | :meth:`assign_device_to_site() <dnacentersdk.api.v1_2_10.sites.Sites.assign_device_to_site>`                                                                          |
|                      |                                                         | :meth:`create_site() <dnacentersdk.api.v1_2_10.sites.Sites.create_site>`                                                                                              |
|                      |                                                         | :meth:`get_site_health() <dnacentersdk.api.v1_2_10.sites.Sites.get_site_health>`                                                                                      |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`swim <swim_1_2_10>`                               | :meth:`get_software_image_details() <dnacentersdk.api.v1_2_10.swim.Swim.get_software_image_details>`                                                                  |
|                      |                                                         | :meth:`import_local_software_image() <dnacentersdk.api.v1_2_10.swim.Swim.import_local_software_image>`                                                                |
|                      |                                                         | :meth:`import_software_image_via_url() <dnacentersdk.api.v1_2_10.swim.Swim.import_software_image_via_url>`                                                            |
|                      |                                                         | :meth:`trigger_software_image_activation() <dnacentersdk.api.v1_2_10.swim.Swim.trigger_software_image_activation>`                                                    |
|                      |                                                         | :meth:`trigger_software_image_distribution() <dnacentersdk.api.v1_2_10.swim.Swim.trigger_software_image_distribution>`                                                |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`tag <tag_1_2_10>`                                 | :meth:`add_members_to_the_tag() <dnacentersdk.api.v1_2_10.tag.Tag.add_members_to_the_tag>`                                                                            |
|                      |                                                         | :meth:`create_tag() <dnacentersdk.api.v1_2_10.tag.Tag.create_tag>`                                                                                                    |
|                      |                                                         | :meth:`delete_tag() <dnacentersdk.api.v1_2_10.tag.Tag.delete_tag>`                                                                                                    |
|                      |                                                         | :meth:`get_tag() <dnacentersdk.api.v1_2_10.tag.Tag.get_tag>`                                                                                                          |
|                      |                                                         | :meth:`get_tag_by_id() <dnacentersdk.api.v1_2_10.tag.Tag.get_tag_by_id>`                                                                                              |
|                      |                                                         | :meth:`get_tag_count() <dnacentersdk.api.v1_2_10.tag.Tag.get_tag_count>`                                                                                              |
|                      |                                                         | :meth:`get_tag_member_count() <dnacentersdk.api.v1_2_10.tag.Tag.get_tag_member_count>`                                                                                |
|                      |                                                         | :meth:`get_tag_members_by_id() <dnacentersdk.api.v1_2_10.tag.Tag.get_tag_members_by_id>`                                                                              |
|                      |                                                         | :meth:`get_tag_resource_types() <dnacentersdk.api.v1_2_10.tag.Tag.get_tag_resource_types>`                                                                            |
|                      |                                                         | :meth:`remove_tag_member() <dnacentersdk.api.v1_2_10.tag.Tag.remove_tag_member>`                                                                                      |
|                      |                                                         | :meth:`update_tag() <dnacentersdk.api.v1_2_10.tag.Tag.update_tag>`                                                                                                    |
|                      |                                                         | :meth:`updates_tag_membership() <dnacentersdk.api.v1_2_10.tag.Tag.updates_tag_membership>`                                                                            |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`task <task_1_2_10>`                               | :meth:`get_task_by_id() <dnacentersdk.api.v1_2_10.task.Task.get_task_by_id>`                                                                                          |
|                      |                                                         | :meth:`get_task_by_operationid() <dnacentersdk.api.v1_2_10.task.Task.get_task_by_operationid>`                                                                        |
|                      |                                                         | :meth:`get_task_count() <dnacentersdk.api.v1_2_10.task.Task.get_task_count>`                                                                                          |
|                      |                                                         | :meth:`get_task_tree() <dnacentersdk.api.v1_2_10.task.Task.get_task_tree>`                                                                                            |
|                      |                                                         | :meth:`get_tasks() <dnacentersdk.api.v1_2_10.task.Task.get_tasks>`                                                                                                    |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+
|                      | :ref:`template_programmer <template_programmer_1_2_10>` | :meth:`create_project() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.create_project>`                                                             |
|                      |                                                         | :meth:`create_template() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.create_template>`                                                           |
|                      |                                                         | :meth:`delete_project() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.delete_project>`                                                             |
|                      |                                                         | :meth:`delete_template() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.delete_template>`                                                           |
|                      |                                                         | :meth:`deploy_template() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.deploy_template>`                                                           |
|                      |                                                         | :meth:`get_projects() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.get_projects>`                                                                 |
|                      |                                                         | :meth:`get_template_deployment_status() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.get_template_deployment_status>`                             |
|                      |                                                         | :meth:`get_template_details() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.get_template_details>`                                                 |
|                      |                                                         | :meth:`get_template_versions() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.get_template_versions>`                                               |
|                      |                                                         | :meth:`gets_the_templates_available() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.gets_the_templates_available>`                                 |
|                      |                                                         | :meth:`preview_template() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.preview_template>`                                                         |
|                      |                                                         | :meth:`update_project() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.update_project>`                                                             |
|                      |                                                         | :meth:`update_template() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.update_template>`                                                           |
|                      |                                                         | :meth:`version_template() <dnacentersdk.api.v1_2_10.template_programmer.TemplateProgrammer.version_template>`                                                         |
+----------------------+---------------------------------------------------------+-----------------------------------------------------------------------------------------------------------------------------------------------------------------------+